@@ -17,7 +17,7 @@ use base qw(Exporter);    ## no critic (ProhibitUseBase)
 our @EXPORT_OK = 'breakdown';
 
 # Specify package version
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 # Dispatch table of functions to handle different ref types for the spec
 # hashref's values
@@ -82,7 +82,7 @@ __END__
 =pod
 
 =for stopwords
-sublists Unhandled tradename licensable MERCHANTABILITY hashrefs
+sublists Unhandled tradename licensable MERCHANTABILITY hashrefs CPAN AnnoCPAN
 
 =head1 NAME
 
@@ -90,7 +90,7 @@ List::Breakdown - Build list sublists matching conditions
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =head1 DESCRIPTION
 
@@ -147,7 +147,7 @@ a shortcut) for which the regular expression matched.
 
 =head1 EXAMPLES
 
-=head2 
+=head2 Collecting troublesome records
 
 Suppose you have a list of strings from a very legacy system that you need to
 regularly check for problematic characters, alerting you to problems with an
@@ -171,7 +171,7 @@ you've seen before for review:
     );
 
 Notice that you don't have to wrap a quoted regular expression to match in a
-`sub` subroutine reference, as a convenience shortcut.
+C<sub> subroutine reference, as a convenience shortcut.
 
 Applying the bucket structure like so:
 
@@ -301,7 +301,17 @@ this module. Legal reference types are C<HASH>, C<CODE>, and C<Regexp>.
 
 =head1 DEPENDENCIES
 
-Perl 5.6 and the core modules C<Carp> and C<Exporter>.
+=over 4
+
+=item Perl 5.6.0 or newer
+
+=item C<base>
+
+=item C<Carp>
+
+=item C<Exporter>
+
+=back
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
@@ -322,6 +332,28 @@ You can find documentation for this module with the C<perldoc> command.
 
     perldoc List::Breakdown
 
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker (report bugs here)
+
+<http://rt.cpan.org/NoAuth/Bugs.html?Dist=List-Breakdown>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+<http://annocpan.org/dist/List-Breakdown>
+
+=item * CPAN Ratings
+
+<http://cpanratings.perl.org/d/List-Breakdown>
+
+=item * Search CPAN
+
+<http://search.cpan.org/dist/List-Breakdown/>
+
+=back
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright (C) 2017 Tom Ryder
